@@ -218,6 +218,9 @@ class ConfigBase:
         else:
             self._include = tuple()
 
+        if self._path is not None:
+            self.load()
+
         return self
 
     @classmethod
@@ -252,7 +255,24 @@ class ConfigBase:
 
     def load(self):
         if not hasattr(self, '_blob') or self._mtime_changed():
-            self._blob = self._load_type()
+            msg = (f'The config at {self._path!r} '
+                   'should not be empty!')
+            empty_error = exc.EmptyConfigError(msg)
+
+            try:
+                _blob = self._load_type()
+            except json.decoder.JSONDecodeError as e:
+                raise empty_error from e
+            except SyntaxError as e:
+                if e.msg == 'unexpected EOF while parsing' and e.offset == 0:
+                    raise empty_error from e
+                else:
+                    raise e
+
+            if _blob is None:
+                raise empty_error
+
+            self._blob = _blob
 
         return self._blob
 
@@ -269,7 +289,13 @@ class ConfigBase:
         elif format == 'py':
             return pformat(config)
         elif format == 'yaml':
-            return yaml.dump(config, default_flow_style=False)
+            try:
+                return yaml.dump(config, default_flow_style=False)
+            except NameError as e:
+                msg = (f'Module yaml was not found while tyring to load {self._path}\n'
+                       'To resolve this issue reinstall orthauth with yaml '
+                       'support enabled\n or reformat your config to .py')
+                raise ModuleNotFoundError(msg) from e
         else:
             raise NotImplementedError(f'serialization to {format!r} is not ready')
 
@@ -326,7 +352,7 @@ class ConfigBase:
             except NameError as e:
                 msg = (f'Module yaml was not found while tyring to load {self._path}\n'
                        'To resolve this issue reinstall orthauth with yaml '
-                       'support enabled\n or reform your config to .py')
+                       'support enabled\n or reformat your config to .py')
                 raise ModuleNotFoundError(msg) from e
 
     @staticmethod
@@ -565,8 +591,9 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
         if not ucp.parent.exists():
             ucp.parent.mkdir(parents=True)
 
+        string = self._serialize_user_config(format)
         with open(ucp, 'wt') as f:
-            f.write(self._serialize_user_config(format))
+            f.write(string)
 
     def get_list(self, variable_name):
         """ if you know a variable holds a list use this """
@@ -795,7 +822,7 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
                 if len(d) == 1 and d[0] is None:
                     return
                 else:
-                    return str(d[0])
+                    return d[0]
 
         for f, v in zip((getenv,
                          get_uc,
@@ -949,7 +976,7 @@ class UserConfig(ConfigBase):
                 if len(d) == 1 and d[0] is None:
                     return
                 else:
-                    return str(d[0])
+                    return d[0]
 
         for f, v in zip((getenv,
                          self._get_path if for_path else self._get,
